Learn R Programming

bracketeer (version 0.1.1)

remaining: Select entrants remaining in the current transition source pool

Description

Select entrants remaining in the current transition source pool

Usage

remaining()

Arguments

Value

A bracketeer_selector object.