Learn R Programming

bracketeer (version 0.1.1)

round_robin: Create a round robin tournament

Description

Round robin tournament where each participant plays every other participant.

Usage

round_robin(participants, ...)

Value

A round_robin_bracket object

Arguments

participants

Character vector of participant names, or a data.frame with a 'name' column and optional 'seed' column.

...

Additional arguments passed to bracket constructors or tournament stage-verb dispatch methods.

Examples

Run this code
# Simple round robin
trn <- tournament(c("A", "B", "C", "D")) |>
  round_robin("groups")

# Multiple groups (World Cup style)
teams <- paste("Team", sprintf("%02d", 1:32))
trn <- tournament(teams) |>
  round_robin("groups", groups = 8)

Run the code above in your browser using DataLab