Learn R Programming

bracketeer (version 0.1.1)

swiss: Create a Swiss-system tournament

Description

Swiss system pairs participants by similar records each round.

Usage

swiss(participants, ...)

Value

A swiss_bracket object

Arguments

participants

Character vector of participant names, or a data.frame with a 'name' column and optional 'seed' column.

...

Additional arguments passed to bracket constructors or tournament stage-verb dispatch methods.

Examples

Run this code
# Swiss system followed by top-cut playoffs
teams <- paste("Team", LETTERS[1:16])
trn <- tournament(teams) |>
  swiss("open", rounds = 5) |>
  single_elim("playoffs", take = top_n(8))

Run the code above in your browser using DataLab